##  Description
Provider typically refers to the third-party entity that takes on the role of ownership and host for an application's underlying technology, service (IT component), or plans and executes initiatives. It indicates the responsible party or system that maintains and updates the technology over time.
For example, suppose an organization offers a web service to other systems or applications. In that case, the system providing that web service is considered the provider of that service in SAP LeanIX. The provider is responsible for any changes or updates to the web service and its associated documentation, ensuring that it remains operational and up-to-date for its consumers.
This example shows the relations between the provider, IT component, and initiative: SAP is the provider for the SAP Leonardo backend. Consultancy or IT solution provider (e.g., Accenture, Deloitte, Capgemini, EY) is the provider to plan and execute your SAP S/4HANA transformation initiative.
Overview of all relations to/from provider:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio226357e8022b41c7b0d416134b710a82_LowRes.png)
